
Test doc
========

This is a test document for the youtube-links extension.

.. youtube:: https://www.youtube.com/watch?v=dQw4w9WgXcQ

.. youtube:: https://www.youtube.com/watch?v=abc123def456
   :title: Custom Title Video

.. toctree::
    :hidden:

    myst-test
